@@ -6,10 +6,11 @@ Type annotations for fis service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_fis import FISClient
+    from boto3.session import Session
+    from mypy_boto3_fis.client import FISClient
 
-    client: FISClient = boto3.client("fis")
+    session = Session()
+    client: FISClient = session.client("fis")
     ```
 """
 from typing import Any, Dict, Mapping, Sequence, Type
@@ -18,6 +19,7 @@ from botocore.client import BaseClient, ClientMeta
 
 from .type_defs import (
     CreateExperimentTemplateActionInputTypeDef,
+    CreateExperimentTemplateLogConfigurationInputTypeDef,
     CreateExperimentTemplateResponseTypeDef,
     CreateExperimentTemplateStopConditionInputTypeDef,
     CreateExperimentTemplateTargetInputTypeDef,
@@ -25,13 +27,16 @@ from .type_defs import (
     GetActionResponseTypeDef,
     GetExperimentResponseTypeDef,
     GetExperimentTemplateResponseTypeDef,
+    GetTargetResourceTypeResponseTypeDef,
     ListActionsResponseTypeDef,
     ListExperimentsResponseTypeDef,
     ListExperimentTemplatesResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    ListTargetResourceTypesResponseTypeDef,
     StartExperimentResponseTypeDef,
     StopExperimentResponseTypeDef,
     UpdateExperimentTemplateActionInputItemTypeDef,
+    UpdateExperimentTemplateLogConfigurationInputTypeDef,
     UpdateExperimentTemplateResponseTypeDef,
     UpdateExperimentTemplateStopConditionInputTypeDef,
     UpdateExperimentTemplateTargetInputTypeDef,
@@ -58,7 +63,7 @@ class Exceptions:
 
 class FISClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html)
     """
 
@@ -68,13 +73,16 @@ class FISClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         FISClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#can_paginate)
         """
 
@@ -87,12 +95,13 @@ class FISClient(BaseClient):
         actions: Mapping[str, "CreateExperimentTemplateActionInputTypeDef"],
         roleArn: str,
         targets: Mapping[str, "CreateExperimentTemplateTargetInputTypeDef"] = ...,
-        tags: Mapping[str, str] = ...
+        tags: Mapping[str, str] = ...,
+        logConfiguration: "CreateExperimentTemplateLogConfigurationInputTypeDef" = ...
     ) -> CreateExperimentTemplateResponseTypeDef:
         """
         Creates an experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.create_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.create_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#create_experiment_template)
         """
 
@@ -100,7 +109,7 @@ class FISClient(BaseClient):
         """
         Deletes the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.delete_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.delete_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#delete_experiment_template)
         """
 
@@ -114,7 +123,7 @@ class FISClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#generate_presigned_url)
         """
 
@@ -122,7 +131,7 @@ class FISClient(BaseClient):
         """
         Gets information about the specified FIS action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.get_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.get_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#get_action)
         """
 
@@ -130,7 +139,7 @@ class FISClient(BaseClient):
         """
         Gets information about the specified experiment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.get_experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.get_experiment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#get_experiment)
         """
 
@@ -138,17 +147,27 @@ class FISClient(BaseClient):
         """
         Gets information about the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.get_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.get_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#get_experiment_template)
         """
 
+    def get_target_resource_type(
+        self, *, resourceType: str
+    ) -> GetTargetResourceTypeResponseTypeDef:
+        """
+        Gets information about the specified resource type.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.get_target_resource_type)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#get_target_resource_type)
+        """
+
     def list_actions(
         self, *, maxResults: int = ..., nextToken: str = ...
     ) -> ListActionsResponseTypeDef:
         """
         Lists the available FIS actions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.list_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.list_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_actions)
         """
 
@@ -158,7 +177,7 @@ class FISClient(BaseClient):
         """
         Lists your experiment templates.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.list_experiment_templates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.list_experiment_templates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_experiment_templates)
         """
 
@@ -168,7 +187,7 @@ class FISClient(BaseClient):
         """
         Lists your experiments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.list_experiments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.list_experiments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_experiments)
         """
 
@@ -176,17 +195,27 @@ class FISClient(BaseClient):
         """
         Lists the tags for the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_tags_for_resource)
         """
 
+    def list_target_resource_types(
+        self, *, maxResults: int = ..., nextToken: str = ...
+    ) -> ListTargetResourceTypesResponseTypeDef:
+        """
+        Lists the target resource types.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.list_target_resource_types)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_target_resource_types)
+        """
+
     def start_experiment(
         self, *, clientToken: str, experimentTemplateId: str, tags: Mapping[str, str] = ...
     ) -> StartExperimentResponseTypeDef:
         """
         Starts running an experiment from the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.start_experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.start_experiment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#start_experiment)
         """
 
@@ -194,7 +223,7 @@ class FISClient(BaseClient):
         """
         Stops the specified experiment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.stop_experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.stop_experiment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#stop_experiment)
         """
 
@@ -202,7 +231,7 @@ class FISClient(BaseClient):
         """
         Applies the specified tags to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#tag_resource)
         """
 
@@ -210,7 +239,7 @@ class FISClient(BaseClient):
         """
         Removes the specified tags from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#untag_resource)
         """
 
@@ -222,11 +251,12 @@ class FISClient(BaseClient):
         stopConditions: Sequence["UpdateExperimentTemplateStopConditionInputTypeDef"] = ...,
         targets: Mapping[str, "UpdateExperimentTemplateTargetInputTypeDef"] = ...,
         actions: Mapping[str, "UpdateExperimentTemplateActionInputItemTypeDef"] = ...,
-        roleArn: str = ...
+        roleArn: str = ...,
+        logConfiguration: "UpdateExperimentTemplateLogConfigurationInputTypeDef" = ...
     ) -> UpdateExperimentTemplateResponseTypeDef:
         """
         Updates the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/fis.html#FIS.Client.update_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/fis.html#FIS.Client.update_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#update_experiment_template)
         """
