@@ -19,7 +19,13 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ExperimentActionStatusType", "ExperimentStatusType", "ServiceName")
+__all__ = (
+    "ExperimentActionStatusType",
+    "ExperimentStatusType",
+    "FISServiceName",
+    "ServiceName",
+    "ResourceServiceName",
+)
 
 
 ExperimentActionStatusType = Literal[
@@ -28,6 +34,7 @@ ExperimentActionStatusType = Literal[
 ExperimentStatusType = Literal[
     "completed", "failed", "initiating", "pending", "running", "stopped", "stopping"
 ]
+FISServiceName = Literal["fis"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -59,6 +66,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -181,6 +189,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -329,3 +338,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
