@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import ExperimentActionStatusType, ExperimentStatusType
 
 if sys.version_info >= (3, 9):
@@ -98,118 +100,74 @@ __all__ = (
 ActionParameterTypeDef = TypedDict(
     "ActionParameterTypeDef",
     {
-        "description": str,
-        "required": bool,
+        "description": NotRequired[str],
+        "required": NotRequired[bool],
     },
-    total=False,
 )
 
 ActionSummaryTypeDef = TypedDict(
     "ActionSummaryTypeDef",
     {
-        "id": str,
-        "description": str,
-        "targets": Dict[str, "ActionTargetTypeDef"],
-        "tags": Dict[str, str],
+        "id": NotRequired[str],
+        "description": NotRequired[str],
+        "targets": NotRequired[Dict[str, "ActionTargetTypeDef"]],
+        "tags": NotRequired[Dict[str, str]],
     },
-    total=False,
 )
 
 ActionTargetTypeDef = TypedDict(
     "ActionTargetTypeDef",
     {
-        "resourceType": str,
+        "resourceType": NotRequired[str],
     },
-    total=False,
 )
 
 ActionTypeDef = TypedDict(
     "ActionTypeDef",
     {
-        "id": str,
-        "description": str,
-        "parameters": Dict[str, "ActionParameterTypeDef"],
-        "targets": Dict[str, "ActionTargetTypeDef"],
-        "tags": Dict[str, str],
+        "id": NotRequired[str],
+        "description": NotRequired[str],
+        "parameters": NotRequired[Dict[str, "ActionParameterTypeDef"]],
+        "targets": NotRequired[Dict[str, "ActionTargetTypeDef"]],
+        "tags": NotRequired[Dict[str, str]],
     },
-    total=False,
 )
 
-_RequiredCreateExperimentTemplateActionInputTypeDef = TypedDict(
-    "_RequiredCreateExperimentTemplateActionInputTypeDef",
+CreateExperimentTemplateActionInputTypeDef = TypedDict(
+    "CreateExperimentTemplateActionInputTypeDef",
     {
         "actionId": str,
+        "description": NotRequired[str],
+        "parameters": NotRequired[Mapping[str, str]],
+        "targets": NotRequired[Mapping[str, str]],
+        "startAfter": NotRequired[Sequence[str]],
     },
 )
-_OptionalCreateExperimentTemplateActionInputTypeDef = TypedDict(
-    "_OptionalCreateExperimentTemplateActionInputTypeDef",
-    {
-        "description": str,
-        "parameters": Mapping[str, str],
-        "targets": Mapping[str, str],
-        "startAfter": Sequence[str],
-    },
-    total=False,
-)
 
-
-class CreateExperimentTemplateActionInputTypeDef(
-    _RequiredCreateExperimentTemplateActionInputTypeDef,
-    _OptionalCreateExperimentTemplateActionInputTypeDef,
-):
-    pass
-
-
-_RequiredCreateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
-    "_RequiredCreateExperimentTemplateLogConfigurationInputTypeDef",
+CreateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
+    "CreateExperimentTemplateLogConfigurationInputTypeDef",
     {
         "logSchemaVersion": int,
+        "cloudWatchLogsConfiguration": NotRequired[
+            "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef"
+        ],
+        "s3Configuration": NotRequired["ExperimentTemplateS3LogConfigurationInputTypeDef"],
     },
 )
-_OptionalCreateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
-    "_OptionalCreateExperimentTemplateLogConfigurationInputTypeDef",
-    {
-        "cloudWatchLogsConfiguration": "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef",
-        "s3Configuration": "ExperimentTemplateS3LogConfigurationInputTypeDef",
-    },
-    total=False,
-)
 
-
-class CreateExperimentTemplateLogConfigurationInputTypeDef(
-    _RequiredCreateExperimentTemplateLogConfigurationInputTypeDef,
-    _OptionalCreateExperimentTemplateLogConfigurationInputTypeDef,
-):
-    pass
-
-
-_RequiredCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateExperimentTemplateRequestRequestTypeDef",
+CreateExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "CreateExperimentTemplateRequestRequestTypeDef",
     {
         "clientToken": str,
         "description": str,
         "stopConditions": Sequence["CreateExperimentTemplateStopConditionInputTypeDef"],
         "actions": Mapping[str, "CreateExperimentTemplateActionInputTypeDef"],
         "roleArn": str,
+        "targets": NotRequired[Mapping[str, "CreateExperimentTemplateTargetInputTypeDef"]],
+        "tags": NotRequired[Mapping[str, str]],
+        "logConfiguration": NotRequired["CreateExperimentTemplateLogConfigurationInputTypeDef"],
     },
 )
-_OptionalCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateExperimentTemplateRequestRequestTypeDef",
-    {
-        "targets": Mapping[str, "CreateExperimentTemplateTargetInputTypeDef"],
-        "tags": Mapping[str, str],
-        "logConfiguration": "CreateExperimentTemplateLogConfigurationInputTypeDef",
-    },
-    total=False,
-)
-
-
-class CreateExperimentTemplateRequestRequestTypeDef(
-    _RequiredCreateExperimentTemplateRequestRequestTypeDef,
-    _OptionalCreateExperimentTemplateRequestRequestTypeDef,
-):
-    pass
-
 
 CreateExperimentTemplateResponseTypeDef = TypedDict(
     "CreateExperimentTemplateResponseTypeDef",
@@ -219,53 +177,25 @@ CreateExperimentTemplateResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateExperimentTemplateStopConditionInputTypeDef = TypedDict(
-    "_RequiredCreateExperimentTemplateStopConditionInputTypeDef",
+CreateExperimentTemplateStopConditionInputTypeDef = TypedDict(
+    "CreateExperimentTemplateStopConditionInputTypeDef",
     {
         "source": str,
+        "value": NotRequired[str],
     },
 )
-_OptionalCreateExperimentTemplateStopConditionInputTypeDef = TypedDict(
-    "_OptionalCreateExperimentTemplateStopConditionInputTypeDef",
-    {
-        "value": str,
-    },
-    total=False,
-)
 
-
-class CreateExperimentTemplateStopConditionInputTypeDef(
-    _RequiredCreateExperimentTemplateStopConditionInputTypeDef,
-    _OptionalCreateExperimentTemplateStopConditionInputTypeDef,
-):
-    pass
-
-
-_RequiredCreateExperimentTemplateTargetInputTypeDef = TypedDict(
-    "_RequiredCreateExperimentTemplateTargetInputTypeDef",
+CreateExperimentTemplateTargetInputTypeDef = TypedDict(
+    "CreateExperimentTemplateTargetInputTypeDef",
     {
         "resourceType": str,
         "selectionMode": str,
+        "resourceArns": NotRequired[Sequence[str]],
+        "resourceTags": NotRequired[Mapping[str, str]],
+        "filters": NotRequired[Sequence["ExperimentTemplateTargetInputFilterTypeDef"]],
+        "parameters": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateExperimentTemplateTargetInputTypeDef = TypedDict(
-    "_OptionalCreateExperimentTemplateTargetInputTypeDef",
-    {
-        "resourceArns": Sequence[str],
-        "resourceTags": Mapping[str, str],
-        "filters": Sequence["ExperimentTemplateTargetInputFilterTypeDef"],
-        "parameters": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateExperimentTemplateTargetInputTypeDef(
-    _RequiredCreateExperimentTemplateTargetInputTypeDef,
-    _OptionalCreateExperimentTemplateTargetInputTypeDef,
-):
-    pass
-
 
 DeleteExperimentTemplateRequestRequestTypeDef = TypedDict(
     "DeleteExperimentTemplateRequestRequestTypeDef",
@@ -285,116 +215,107 @@ DeleteExperimentTemplateResponseTypeDef = TypedDict(
 ExperimentActionStateTypeDef = TypedDict(
     "ExperimentActionStateTypeDef",
     {
-        "status": ExperimentActionStatusType,
-        "reason": str,
+        "status": NotRequired[ExperimentActionStatusType],
+        "reason": NotRequired[str],
     },
-    total=False,
 )
 
 ExperimentActionTypeDef = TypedDict(
     "ExperimentActionTypeDef",
     {
-        "actionId": str,
-        "description": str,
-        "parameters": Dict[str, str],
-        "targets": Dict[str, str],
-        "startAfter": List[str],
-        "state": "ExperimentActionStateTypeDef",
-        "startTime": datetime,
-        "endTime": datetime,
+        "actionId": NotRequired[str],
+        "description": NotRequired[str],
+        "parameters": NotRequired[Dict[str, str]],
+        "targets": NotRequired[Dict[str, str]],
+        "startAfter": NotRequired[List[str]],
+        "state": NotRequired["ExperimentActionStateTypeDef"],
+        "startTime": NotRequired[datetime],
+        "endTime": NotRequired[datetime],
     },
-    total=False,
 )
 
 ExperimentCloudWatchLogsLogConfigurationTypeDef = TypedDict(
     "ExperimentCloudWatchLogsLogConfigurationTypeDef",
     {
-        "logGroupArn": str,
+        "logGroupArn": NotRequired[str],
     },
-    total=False,
 )
 
 ExperimentLogConfigurationTypeDef = TypedDict(
     "ExperimentLogConfigurationTypeDef",
     {
-        "cloudWatchLogsConfiguration": "ExperimentCloudWatchLogsLogConfigurationTypeDef",
-        "s3Configuration": "ExperimentS3LogConfigurationTypeDef",
-        "logSchemaVersion": int,
+        "cloudWatchLogsConfiguration": NotRequired[
+            "ExperimentCloudWatchLogsLogConfigurationTypeDef"
+        ],
+        "s3Configuration": NotRequired["ExperimentS3LogConfigurationTypeDef"],
+        "logSchemaVersion": NotRequired[int],
     },
-    total=False,
 )
 
 ExperimentS3LogConfigurationTypeDef = TypedDict(
     "ExperimentS3LogConfigurationTypeDef",
     {
-        "bucketName": str,
-        "prefix": str,
+        "bucketName": NotRequired[str],
+        "prefix": NotRequired[str],
     },
-    total=False,
 )
 
 ExperimentStateTypeDef = TypedDict(
     "ExperimentStateTypeDef",
     {
-        "status": ExperimentStatusType,
-        "reason": str,
+        "status": NotRequired[ExperimentStatusType],
+        "reason": NotRequired[str],
     },
-    total=False,
 )
 
 ExperimentStopConditionTypeDef = TypedDict(
     "ExperimentStopConditionTypeDef",
     {
-        "source": str,
-        "value": str,
+        "source": NotRequired[str],
+        "value": NotRequired[str],
     },
-    total=False,
 )
 
 ExperimentSummaryTypeDef = TypedDict(
     "ExperimentSummaryTypeDef",
     {
-        "id": str,
-        "experimentTemplateId": str,
-        "state": "ExperimentStateTypeDef",
-        "creationTime": datetime,
-        "tags": Dict[str, str],
+        "id": NotRequired[str],
+        "experimentTemplateId": NotRequired[str],
+        "state": NotRequired["ExperimentStateTypeDef"],
+        "creationTime": NotRequired[datetime],
+        "tags": NotRequired[Dict[str, str]],
     },
-    total=False,
 )
 
 ExperimentTargetFilterTypeDef = TypedDict(
     "ExperimentTargetFilterTypeDef",
     {
-        "path": str,
-        "values": List[str],
+        "path": NotRequired[str],
+        "values": NotRequired[List[str]],
     },
-    total=False,
 )
 
 ExperimentTargetTypeDef = TypedDict(
     "ExperimentTargetTypeDef",
     {
-        "resourceType": str,
-        "resourceArns": List[str],
-        "resourceTags": Dict[str, str],
-        "filters": List["ExperimentTargetFilterTypeDef"],
-        "selectionMode": str,
-        "parameters": Dict[str, str],
+        "resourceType": NotRequired[str],
+        "resourceArns": NotRequired[List[str]],
+        "resourceTags": NotRequired[Dict[str, str]],
+        "filters": NotRequired[List["ExperimentTargetFilterTypeDef"]],
+        "selectionMode": NotRequired[str],
+        "parameters": NotRequired[Dict[str, str]],
     },
-    total=False,
 )
 
 ExperimentTemplateActionTypeDef = TypedDict(
     "ExperimentTemplateActionTypeDef",
     {
-        "actionId": str,
-        "description": str,
-        "parameters": Dict[str, str],
-        "targets": Dict[str, str],
-        "startAfter": List[str],
+        "actionId": NotRequired[str],
+        "description": NotRequired[str],
+        "parameters": NotRequired[Dict[str, str]],
+        "targets": NotRequired[Dict[str, str]],
+        "startAfter": NotRequired[List[str]],
     },
-    total=False,
 )
 
 ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef = TypedDict(
@@ -407,80 +328,62 @@ ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef = TypedDict(
 ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef = TypedDict(
     "ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef",
     {
-        "logGroupArn": str,
+        "logGroupArn": NotRequired[str],
     },
-    total=False,
 )
 
 ExperimentTemplateLogConfigurationTypeDef = TypedDict(
     "ExperimentTemplateLogConfigurationTypeDef",
     {
-        "cloudWatchLogsConfiguration": "ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef",
-        "s3Configuration": "ExperimentTemplateS3LogConfigurationTypeDef",
-        "logSchemaVersion": int,
+        "cloudWatchLogsConfiguration": NotRequired[
+            "ExperimentTemplateCloudWatchLogsLogConfigurationTypeDef"
+        ],
+        "s3Configuration": NotRequired["ExperimentTemplateS3LogConfigurationTypeDef"],
+        "logSchemaVersion": NotRequired[int],
     },
-    total=False,
 )
 
-_RequiredExperimentTemplateS3LogConfigurationInputTypeDef = TypedDict(
-    "_RequiredExperimentTemplateS3LogConfigurationInputTypeDef",
+ExperimentTemplateS3LogConfigurationInputTypeDef = TypedDict(
+    "ExperimentTemplateS3LogConfigurationInputTypeDef",
     {
         "bucketName": str,
+        "prefix": NotRequired[str],
     },
 )
-_OptionalExperimentTemplateS3LogConfigurationInputTypeDef = TypedDict(
-    "_OptionalExperimentTemplateS3LogConfigurationInputTypeDef",
-    {
-        "prefix": str,
-    },
-    total=False,
-)
-
-
-class ExperimentTemplateS3LogConfigurationInputTypeDef(
-    _RequiredExperimentTemplateS3LogConfigurationInputTypeDef,
-    _OptionalExperimentTemplateS3LogConfigurationInputTypeDef,
-):
-    pass
-
 
 ExperimentTemplateS3LogConfigurationTypeDef = TypedDict(
     "ExperimentTemplateS3LogConfigurationTypeDef",
     {
-        "bucketName": str,
-        "prefix": str,
+        "bucketName": NotRequired[str],
+        "prefix": NotRequired[str],
     },
-    total=False,
 )
 
 ExperimentTemplateStopConditionTypeDef = TypedDict(
     "ExperimentTemplateStopConditionTypeDef",
     {
-        "source": str,
-        "value": str,
+        "source": NotRequired[str],
+        "value": NotRequired[str],
     },
-    total=False,
 )
 
 ExperimentTemplateSummaryTypeDef = TypedDict(
     "ExperimentTemplateSummaryTypeDef",
     {
-        "id": str,
-        "description": str,
-        "creationTime": datetime,
-        "lastUpdateTime": datetime,
-        "tags": Dict[str, str],
+        "id": NotRequired[str],
+        "description": NotRequired[str],
+        "creationTime": NotRequired[datetime],
+        "lastUpdateTime": NotRequired[datetime],
+        "tags": NotRequired[Dict[str, str]],
     },
-    total=False,
 )
 
 ExperimentTemplateTargetFilterTypeDef = TypedDict(
     "ExperimentTemplateTargetFilterTypeDef",
     {
-        "path": str,
-        "values": List[str],
+        "path": NotRequired[str],
+        "values": NotRequired[List[str]],
     },
-    total=False,
 )
 
 ExperimentTemplateTargetInputFilterTypeDef = TypedDict(
@@ -494,50 +397,47 @@ ExperimentTemplateTargetInputFilterTypeDef = TypedDict(
 ExperimentTemplateTargetTypeDef = TypedDict(
     "ExperimentTemplateTargetTypeDef",
     {
-        "resourceType": str,
-        "resourceArns": List[str],
-        "resourceTags": Dict[str, str],
-        "filters": List["ExperimentTemplateTargetFilterTypeDef"],
-        "selectionMode": str,
-        "parameters": Dict[str, str],
+        "resourceType": NotRequired[str],
+        "resourceArns": NotRequired[List[str]],
+        "resourceTags": NotRequired[Dict[str, str]],
+        "filters": NotRequired[List["ExperimentTemplateTargetFilterTypeDef"]],
+        "selectionMode": NotRequired[str],
+        "parameters": NotRequired[Dict[str, str]],
     },
-    total=False,
 )
 
 ExperimentTemplateTypeDef = TypedDict(
     "ExperimentTemplateTypeDef",
     {
-        "id": str,
-        "description": str,
-        "targets": Dict[str, "ExperimentTemplateTargetTypeDef"],
-        "actions": Dict[str, "ExperimentTemplateActionTypeDef"],
-        "stopConditions": List["ExperimentTemplateStopConditionTypeDef"],
-        "creationTime": datetime,
-        "lastUpdateTime": datetime,
-        "roleArn": str,
-        "tags": Dict[str, str],
-        "logConfiguration": "ExperimentTemplateLogConfigurationTypeDef",
+        "id": NotRequired[str],
+        "description": NotRequired[str],
+        "targets": NotRequired[Dict[str, "ExperimentTemplateTargetTypeDef"]],
+        "actions": NotRequired[Dict[str, "ExperimentTemplateActionTypeDef"]],
+        "stopConditions": NotRequired[List["ExperimentTemplateStopConditionTypeDef"]],
+        "creationTime": NotRequired[datetime],
+        "lastUpdateTime": NotRequired[datetime],
+        "roleArn": NotRequired[str],
+        "tags": NotRequired[Dict[str, str]],
+        "logConfiguration": NotRequired["ExperimentTemplateLogConfigurationTypeDef"],
     },
-    total=False,
 )
 
 ExperimentTypeDef = TypedDict(
     "ExperimentTypeDef",
     {
-        "id": str,
-        "experimentTemplateId": str,
-        "roleArn": str,
-        "state": "ExperimentStateTypeDef",
-        "targets": Dict[str, "ExperimentTargetTypeDef"],
-        "actions": Dict[str, "ExperimentActionTypeDef"],
-        "stopConditions": List["ExperimentStopConditionTypeDef"],
-        "creationTime": datetime,
-        "startTime": datetime,
-        "endTime": datetime,
-        "tags": Dict[str, str],
-        "logConfiguration": "ExperimentLogConfigurationTypeDef",
+        "id": NotRequired[str],
+        "experimentTemplateId": NotRequired[str],
+        "roleArn": NotRequired[str],
+        "state": NotRequired["ExperimentStateTypeDef"],
+        "targets": NotRequired[Dict[str, "ExperimentTargetTypeDef"]],
+        "actions": NotRequired[Dict[str, "ExperimentActionTypeDef"]],
+        "stopConditions": NotRequired[List["ExperimentStopConditionTypeDef"]],
+        "creationTime": NotRequired[datetime],
+        "startTime": NotRequired[datetime],
+        "endTime": NotRequired[datetime],
+        "tags": NotRequired[Dict[str, str]],
+        "logConfiguration": NotRequired["ExperimentLogConfigurationTypeDef"],
     },
-    total=False,
 )
 
 GetActionRequestRequestTypeDef = TypedDict(
@@ -603,10 +503,9 @@ GetTargetResourceTypeResponseTypeDef = TypedDict(
 ListActionsRequestRequestTypeDef = TypedDict(
     "ListActionsRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListActionsResponseTypeDef = TypedDict(
@@ -621,10 +520,9 @@ ListActionsResponseTypeDef = TypedDict(
 ListExperimentTemplatesRequestRequestTypeDef = TypedDict(
     "ListExperimentTemplatesRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListExperimentTemplatesResponseTypeDef = TypedDict(
@@ -639,10 +537,9 @@ ListExperimentTemplatesResponseTypeDef = TypedDict(
 ListExperimentsRequestRequestTypeDef = TypedDict(
     "ListExperimentsRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListExperimentsResponseTypeDef = TypedDict(
@@ -672,10 +569,9 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 ListTargetResourceTypesRequestRequestTypeDef = TypedDict(
     "ListTargetResourceTypesRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListTargetResourceTypesResponseTypeDef = TypedDict(
@@ -698,27 +594,14 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredStartExperimentRequestRequestTypeDef = TypedDict(
-    "_RequiredStartExperimentRequestRequestTypeDef",
+StartExperimentRequestRequestTypeDef = TypedDict(
+    "StartExperimentRequestRequestTypeDef",
     {
         "clientToken": str,
         "experimentTemplateId": str,
+        "tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalStartExperimentRequestRequestTypeDef = TypedDict(
-    "_OptionalStartExperimentRequestRequestTypeDef",
-    {
-        "tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class StartExperimentRequestRequestTypeDef(
-    _RequiredStartExperimentRequestRequestTypeDef, _OptionalStartExperimentRequestRequestTypeDef
-):
-    pass
-
 
 StartExperimentResponseTypeDef = TypedDict(
     "StartExperimentResponseTypeDef",
@@ -754,100 +637,72 @@ TagResourceRequestRequestTypeDef = TypedDict(
 TargetResourceTypeParameterTypeDef = TypedDict(
     "TargetResourceTypeParameterTypeDef",
     {
-        "description": str,
-        "required": bool,
+        "description": NotRequired[str],
+        "required": NotRequired[bool],
     },
-    total=False,
 )
 
 TargetResourceTypeSummaryTypeDef = TypedDict(
     "TargetResourceTypeSummaryTypeDef",
     {
-        "resourceType": str,
-        "description": str,
+        "resourceType": NotRequired[str],
+        "description": NotRequired[str],
     },
-    total=False,
 )
 
 TargetResourceTypeTypeDef = TypedDict(
     "TargetResourceTypeTypeDef",
     {
-        "resourceType": str,
-        "description": str,
-        "parameters": Dict[str, "TargetResourceTypeParameterTypeDef"],
+        "resourceType": NotRequired[str],
+        "description": NotRequired[str],
+        "parameters": NotRequired[Dict[str, "TargetResourceTypeParameterTypeDef"]],
     },
-    total=False,
 )
 
-_RequiredUntagResourceRequestRequestTypeDef = TypedDict(
-    "_RequiredUntagResourceRequestRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
+        "tagKeys": NotRequired[Sequence[str]],
     },
 )
-_OptionalUntagResourceRequestRequestTypeDef = TypedDict(
-    "_OptionalUntagResourceRequestRequestTypeDef",
-    {
-        "tagKeys": Sequence[str],
-    },
-    total=False,
-)
-
-
-class UntagResourceRequestRequestTypeDef(
-    _RequiredUntagResourceRequestRequestTypeDef, _OptionalUntagResourceRequestRequestTypeDef
-):
-    pass
-
 
 UpdateExperimentTemplateActionInputItemTypeDef = TypedDict(
     "UpdateExperimentTemplateActionInputItemTypeDef",
     {
-        "actionId": str,
-        "description": str,
-        "parameters": Mapping[str, str],
-        "targets": Mapping[str, str],
-        "startAfter": Sequence[str],
+        "actionId": NotRequired[str],
+        "description": NotRequired[str],
+        "parameters": NotRequired[Mapping[str, str]],
+        "targets": NotRequired[Mapping[str, str]],
+        "startAfter": NotRequired[Sequence[str]],
     },
-    total=False,
 )
 
 UpdateExperimentTemplateLogConfigurationInputTypeDef = TypedDict(
     "UpdateExperimentTemplateLogConfigurationInputTypeDef",
     {
-        "cloudWatchLogsConfiguration": "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef",
-        "s3Configuration": "ExperimentTemplateS3LogConfigurationInputTypeDef",
-        "logSchemaVersion": int,
+        "cloudWatchLogsConfiguration": NotRequired[
+            "ExperimentTemplateCloudWatchLogsLogConfigurationInputTypeDef"
+        ],
+        "s3Configuration": NotRequired["ExperimentTemplateS3LogConfigurationInputTypeDef"],
+        "logSchemaVersion": NotRequired[int],
     },
-    total=False,
 )
 
-_RequiredUpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateExperimentTemplateRequestRequestTypeDef",
+UpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
+    "UpdateExperimentTemplateRequestRequestTypeDef",
     {
         "id": str,
+        "description": NotRequired[str],
+        "stopConditions": NotRequired[
+            Sequence["UpdateExperimentTemplateStopConditionInputTypeDef"]
+        ],
+        "targets": NotRequired[Mapping[str, "UpdateExperimentTemplateTargetInputTypeDef"]],
+        "actions": NotRequired[Mapping[str, "UpdateExperimentTemplateActionInputItemTypeDef"]],
+        "roleArn": NotRequired[str],
+        "logConfiguration": NotRequired["UpdateExperimentTemplateLogConfigurationInputTypeDef"],
     },
 )
-_OptionalUpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateExperimentTemplateRequestRequestTypeDef",
-    {
-        "description": str,
-        "stopConditions": Sequence["UpdateExperimentTemplateStopConditionInputTypeDef"],
-        "targets": Mapping[str, "UpdateExperimentTemplateTargetInputTypeDef"],
-        "actions": Mapping[str, "UpdateExperimentTemplateActionInputItemTypeDef"],
-        "roleArn": str,
-        "logConfiguration": "UpdateExperimentTemplateLogConfigurationInputTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateExperimentTemplateRequestRequestTypeDef(
-    _RequiredUpdateExperimentTemplateRequestRequestTypeDef,
-    _OptionalUpdateExperimentTemplateRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateExperimentTemplateResponseTypeDef = TypedDict(
     "UpdateExperimentTemplateResponseTypeDef",
@@ -857,49 +712,22 @@ UpdateExperimentTemplateResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateExperimentTemplateStopConditionInputTypeDef = TypedDict(
-    "_RequiredUpdateExperimentTemplateStopConditionInputTypeDef",
+UpdateExperimentTemplateStopConditionInputTypeDef = TypedDict(
+    "UpdateExperimentTemplateStopConditionInputTypeDef",
     {
         "source": str,
+        "value": NotRequired[str],
     },
 )
-_OptionalUpdateExperimentTemplateStopConditionInputTypeDef = TypedDict(
-    "_OptionalUpdateExperimentTemplateStopConditionInputTypeDef",
-    {
-        "value": str,
-    },
-    total=False,
-)
 
-
-class UpdateExperimentTemplateStopConditionInputTypeDef(
-    _RequiredUpdateExperimentTemplateStopConditionInputTypeDef,
-    _OptionalUpdateExperimentTemplateStopConditionInputTypeDef,
-):
-    pass
-
-
-_RequiredUpdateExperimentTemplateTargetInputTypeDef = TypedDict(
-    "_RequiredUpdateExperimentTemplateTargetInputTypeDef",
+UpdateExperimentTemplateTargetInputTypeDef = TypedDict(
+    "UpdateExperimentTemplateTargetInputTypeDef",
     {
         "resourceType": str,
         "selectionMode": str,
+        "resourceArns": NotRequired[Sequence[str]],
+        "resourceTags": NotRequired[Mapping[str, str]],
+        "filters": NotRequired[Sequence["ExperimentTemplateTargetInputFilterTypeDef"]],
+        "parameters": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalUpdateExperimentTemplateTargetInputTypeDef = TypedDict(
-    "_OptionalUpdateExperimentTemplateTargetInputTypeDef",
-    {
-        "resourceArns": Sequence[str],
-        "resourceTags": Mapping[str, str],
-        "filters": Sequence["ExperimentTemplateTargetInputFilterTypeDef"],
-        "parameters": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class UpdateExperimentTemplateTargetInputTypeDef(
-    _RequiredUpdateExperimentTemplateTargetInputTypeDef,
-    _OptionalUpdateExperimentTemplateTargetInputTypeDef,
-):
-    pass
